@@ -37,15 +37,6 @@ class DependentService:
         self.dep = dep
 
 
-# Test CustomDecoder
-# def test_custom_decoder():
-#     def decode_int(value: str) -> int:
-#         return int(value)
-
-#     decoder = CustomDecoder(decode=decode_int)
-#     assert decoder.decode("42") == 42
-
-
 # Test RequestParamBase and RequestParam
 def test_request_Param():
     # Test with default value
@@ -445,7 +436,7 @@ def test_param_decoder_override(param_parser: EndpointParser):
 def test_http_excp_with_typealis():
     from lihil import HTTPException, status
 
-    err = HTTPException(problem_status=status.NOT_FOUND)
+    err = HTTPException(status=status.NOT_FOUND)
     assert err.status == 404
 
 
